Chromium Code Reviews

Unified Diff: chrome/browser/child_process_security_policy.h

Issue 113488: Rename RendererSecurityPolicy and move it to browser\. No code change. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
« no previous file with comments | « chrome/browser/browser.vcproj ('k') | chrome/browser/child_process_security_policy.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/child_process_security_policy.h
===================================================================
--- chrome/browser/child_process_security_policy.h (revision 16195)
+++ chrome/browser/child_process_security_policy.h (working copy)
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_RENDERER_HOST_RENDERER_SECURITY_POLICY_H_
-#define CHROME_BROWSER_RENDERER_HOST_RENDERER_SECURITY_POLICY_H_
+#ifndef CHROME_BROWSER_CHILD_PROCESS_SECURITY_POLICY_H_
+#define CHROME_BROWSER_CHILD_PROCESS_SECURITY_POLICY_H_
#include <string>
#include <map>
@@ -17,23 +17,23 @@
class FilePath;
class GURL;
// The RendererSecurityPolicy class is used to grant and revoke security
// capabilities for renderers. For example, it restricts whether a renderer
// is permmitted to loaded file:// URLs based on whether the renderer has ever
// been commanded to load file:// URLs by the browser.
//
// RendererSecurityPolicy is a singleton that may be used on any thread.
//
-class RendererSecurityPolicy {
+class ChildProcessSecurityPolicy {
public:
// Object can only be created through GetInstance() so the constructor is
// private.
- ~RendererSecurityPolicy();
+ ~ChildProcessSecurityPolicy();
- // There is one global RendererSecurityPolicy object for the entire browser
+ // There is one global ChildProcessSecurityPolicy object for the entire browser
// processes. The object returned by this method may be accessed on any
// thread.
- static RendererSecurityPolicy* GetInstance();
+ static ChildProcessSecurityPolicy* GetInstance();
// Web-safe schemes can be requested by any renderer. Once a web-safe scheme
// has been registered, any renderer processes can request URLs with that
@@ -98,9 +98,9 @@
typedef std::set<std::string> SchemeSet;
typedef std::map<int, SecurityState*> SecurityStateMap;
- // Obtain an instance of RendererSecurityPolicy via GetInstance().
- RendererSecurityPolicy();
- friend struct DefaultSingletonTraits<RendererSecurityPolicy>;
+ // Obtain an instance of ChildProcessSecurityPolicy via GetInstance().
+ ChildProcessSecurityPolicy();
+ friend struct DefaultSingletonTraits<ChildProcessSecurityPolicy>;
// You must acquire this lock before reading or writing any members of this
// class. You must not block while holding this lock.
@@ -121,7 +121,7 @@
// not escape this class.
SecurityStateMap security_state_;
- DISALLOW_COPY_AND_ASSIGN(RendererSecurityPolicy);
+ DISALLOW_COPY_AND_ASSIGN(ChildProcessSecurityPolicy);
};
-#endif // CHROME_BROWSER_RENDERER_HOST_RENDERER_SECURITY_POLICY_H_
+#endif // CHROME_BROWSER_CHILD_PROCESS_SECURITY_POLICY_H_
« no previous file with comments | « chrome/browser/browser.vcproj ('k') | chrome/browser/child_process_security_policy.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -17,23 +17,23 @@
class FilePath;
class GURL;
-// The RendererSecurityPolicy class is used to grant and revoke security
+// The ChildProcessSecurityPolicy class is used to grant and revoke security
// capabilities for renderers. For example, it restricts whether a renderer
// is permmitted to loaded file:// URLs based on whether the renderer has ever
@@ -17,23 +17,23 @@
// been commanded to load file:// URLs by the browser.
//
-// RendererSecurityPolicy is a singleton that may be used on any thread.
+// ChildProcessSecurityPolicy is a singleton that may be used on any thread.
//